#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QtGui>
#include <QtNetwork>

#define HTTP_TIMEOUT 15
#define HTTP_MAX_THREADS 32
#define MAX_WORDS_ATTACHED 20
#define MAX_FORMS_ATTACHED 20

#define CODEC_TR "CP1251"
#define OS "Unrecognized OS"

#if defined Q_OS_UNIX
#define CODEC_LOCALE "KOI8R"
#define OS "Unix"
#elif defined Q_OS_WIN
#define CODEC_LOCALE "CP1251"
#define OS "Windows"
//-----------------------------------
#elif defined Q_OS_YOUR_OS_DEFINITION
#define CODEC_LOCALE "YOUR_OS_LOCALE"
#define OS "Your OS name"
#endif
//-----------------------------------

#include "../engine/nausea.h"
#include "../engine/norm.h"
#include "settingswindow.h"
#include <fstream>
#include <sstream>
#include <algorithm>
#include <math.h>

const char name[]	=" v1.1b";
const char copyright[]	="(c) 2008 by Ighor Poteryakhin\nighor@ighor.ru";

extern int completed;

extern bool useproxy;
extern QString proxy;
extern int proxyport;
extern QString proxyuser;
extern QString proxypass;

class Thread;

class MainWindow : public QMainWindow
{
	Q_OBJECT

public:
	MainWindow(QWidget *parent = 0);
	~MainWindow();
	QTreeView *view;
	QStandardItemModel *model;
	SettingsWindow *settingswindow;

	void load(const QStringList&);
	tnorm *norm;

private slots:
	void go();
	void updateurl(const int);
	void saveall2clpbrd();
	void saveall2file();
	void savesel2clpbrd();
	void savesel2file();
	void loadfromclpbrd();
	void loadfromfile();
	void select();
	void about();
	void settings();
	void status(QString, int);

	void open(const QModelIndex&);

private:
	QStatusBar *stat;
	QProgressBar *progress;
	void setupMenus();
	void setupWidgets();

	QMutex mutex;
	QMutex statusmutex;

	int total;

protected:
	void closeEvent(QCloseEvent *event);

};

class QWaitCursor
{
public:
	QWaitCursor(){QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));};
	~QWaitCursor(){QApplication::restoreOverrideCursor();};
};

class Thread : public QThread
{
	Q_OBJECT

public:
	Thread(QStandardItemModel *model, QTreeView *view, QMutex& givenmutex, int id, QObject *parent);
//	~Thread();
	QHttp http;
	static int thrcount;

protected:
	QTimer timer;
	QStandardItemModel *model;
	QTreeView *view;
	tnorm *norm;
	QMutex &mutex;
	int i;
	int reqid;
	void run();
private slots:
	void httpRequestFinished(int requestId, bool error);
	void httpRequestTimeout();
signals:
	void status(QString,int);

};

#endif
